import React, { forwardRef, useRef, useState, useEffect, Fragment } from 'react';
import Glide$1 from '@glidejs/glide';
import { CSSTransition } from 'react-transition-group';
import '@glidejs/glide/dist/css/glide.core.min.css';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var ArrowLeftIcon = forwardRef(function (_ref, ref) {
  var iconSize = _ref.iconSize,
      color = _ref.color,
      rest = _objectWithoutPropertiesLoose(_ref, ["iconSize", "color"]);

  return React.createElement("svg", Object.assign({
    width: iconSize || 20,
    height: iconSize || 20,
    viewBox: "0 0 24 24",
    xmlns: "http://www.w3.org/2000/svg"
  }, rest), React.createElement("polyline", {
    ref: ref,
    fill: "none",
    stroke: color || '#37474F',
    points: "17.5 22 6.5 12 17.5 2",
    strokeLinecap: "round",
    strokeLinejoin: "round",
    strokeWidth: "3"
  }));
});

var ArrowRightIcon = forwardRef(function (_ref, ref) {
  var iconSize = _ref.iconSize,
      color = _ref.color,
      rest = _objectWithoutPropertiesLoose(_ref, ["iconSize", "color"]);

  return React.createElement("svg", Object.assign({
    width: iconSize || 20,
    height: iconSize || 20,
    viewBox: "0 0 24 24",
    xmlns: "http://www.w3.org/2000/svg"
  }, rest), React.createElement("polyline", {
    ref: ref,
    fill: "none",
    stroke: color || '#37474F',
    points: "6.5 2 17.5 12 6.5 22",
    strokeLinecap: "round",
    strokeLinejoin: "round",
    strokeWidth: "3"
  }));
});

var MOUNT_BEFORE = 'mount.before';
var MOUNT_AFTER = 'mount.after';
var UPDATE = 'update';
var PLAY = 'play';
var PAUSE = 'pause';
var BUILD_BEFORE = 'build.before';
var BUILD_AFTER = 'build.after';
var RUN_BEFORE = 'run.before';
var RUN = 'run';
var RUN_AFTER = 'run.after';
var RUN_OFFSET = 'run.offset';
var RUN_START = 'run.start';
var RUN_END = 'run.end';
var MOVE = 'move';
var MOVE_AFTER = 'move.after';
var RESIZE = 'resize';
var SWIPE_START = 'swipe.start';
var SWIPE_MOVE = 'swipe.move';
var SWIPE_END = 'swipe.end';
var TRANSLATE_JUMP = 'translate.jump';

var baseStyles = {"sliderArrow":"_10XKC","sliderArrowNext":"_PZZt_","slideArrowPrev":"_2n9WT"};

var styles = {
  position: 'relative',
  width: '100%',
  overflow: 'hidden',
  boxSizing: 'border-box'
};
var defaultProps = {
  children: null,
  className: 'glide',
  style: {},
  hideArrows: false,
  type: 'slider',
  startAt: 0,
  perView: 1,
  focusAt: 0,
  gap: 10,
  autoplay: false,
  hoverPause: true,
  keyboard: true,
  bound: false,
  swipeThreshold: 80,
  dragThreshold: 120,
  perTouch: false,
  touchRatio: 0.5,
  touchAngle: 45,
  rewind: true,
  rewindDuration: 800,
  direction: 'ltr',
  peek: 0,
  breakpoints: {},
  classes: {
    direction: {
      ltr: 'glide--ltr',
      rtl: 'glide--rtl'
    },
    slider: 'glide--slider',
    carousel: 'glide--carousel',
    swipeable: 'glide--swipeable',
    dragging: 'glide--dragging',
    cloneSlide: 'glide__slide--clone',
    activeNav: 'glide__bullet--active',
    activeSlide: 'glide__slide--active',
    disabledArrow: 'glide__arrow--disabled'
  },
  throttle: 25
};
var Glide = forwardRef(function (props, ref) {
  if (props === void 0) {
    props = defaultProps;
  }

  var _props = props,
      children = _props.children,
      className = _props.className,
      hideArrows = _props.hideArrows,
      arrowSize = _props.arrowSize,
      arrowColor = _props.arrowColor,
      adjustArrowYPosition = _props.adjustArrowYPosition,
      leftArrowComponent = _props.leftArrowComponent,
      rightArrowComponent = _props.rightArrowComponent,
      style = _props.style,
      startAt = _props.startAt,
      animationDuration = _props.animationDuration,
      animationTimingFunc = _props.animationTimingFunc,
      customSlideAnimation = _props.customSlideAnimation,
      mountBefore = _props.mountBefore,
      mountAfter = _props.mountAfter,
      update = _props.update,
      play = _props.play,
      pause = _props.pause,
      buildBefore = _props.buildBefore,
      buildAfter = _props.buildAfter,
      runBefore = _props.runBefore,
      run = _props.run,
      runAfter = _props.runAfter,
      runOffset = _props.runOffset,
      runStart = _props.runStart,
      runEnd = _props.runEnd,
      move = _props.move,
      moveAfter = _props.moveAfter,
      resize = _props.resize,
      swipeStart = _props.swipeStart,
      swipeMove = _props.swipeMove,
      swipeEnd = _props.swipeEnd,
      translateJump = _props.translateJump;
  var glideRef = useRef(null);

  var _useState = useState(startAt === 0 ? 0 : startAt),
      activeSlide = _useState[0],
      setActiveSlide = _useState[1];

  useEffect(function () {
    var glide = new Glide$1(ref ? ref.current : glideRef.current, _extends({}, props, {
      animationDuration: customSlideAnimation ? customSlideAnimation.timeout : animationDuration ? animationDuration : 400,
      animationTimingFunc: customSlideAnimation ? '' : animationTimingFunc ? animationTimingFunc : 'cubic-bezier(0.165, 0.840, 0.440, 1.000)'
    }));
    glide.on(MOUNT_BEFORE, function () {
      if (mountBefore) {
        mountBefore();
      }
    });
    glide.on(MOUNT_AFTER, function () {
      if (mountAfter) {
        mountAfter();
      }
    });
    glide.on(UPDATE, function () {
      if (update) {
        update();
      }
    });
    glide.on(PLAY, function () {
      if (play) {
        play();
      }
    });
    glide.on(PAUSE, function () {
      if (pause) {
        pause();
      }
    });
    glide.on(BUILD_BEFORE, function () {
      if (buildBefore) {
        buildBefore();
      }
    });
    glide.on(BUILD_AFTER, function () {
      if (buildAfter) {
        buildAfter();
      }
    });
    glide.on(RUN_BEFORE, function () {
      if (runBefore) {
        runBefore();
      }
    });
    glide.on(RUN, function () {
      setActiveSlide(glide.index);

      if (run) {
        run();
      }
    });
    glide.on(RUN_AFTER, function () {
      if (runAfter) {
        runAfter();
      }
    });
    glide.on(RUN_OFFSET, function () {
      if (runOffset) {
        runOffset();
      }
    });
    glide.on(RUN_START, function () {
      if (runStart) {
        runStart();
      }
    });
    glide.on(RUN_END, function () {
      if (runEnd) {
        runEnd();
      }
    });
    glide.on(MOVE, function () {
      if (move) {
        move();
      }
    });
    glide.on(MOVE_AFTER, function () {
      if (moveAfter) {
        moveAfter();
      }
    });
    glide.on(RESIZE, function () {
      if (resize) {
        resize();
      }
    });
    glide.on(SWIPE_START, function () {
      if (swipeStart) {
        swipeStart();
      }
    });
    glide.on(SWIPE_MOVE, function () {
      if (swipeMove) {
        swipeMove();
      }
    });
    glide.on(SWIPE_END, function () {
      if (swipeEnd) {
        swipeEnd();
      }
    });
    glide.on(TRANSLATE_JUMP, function () {
      if (translateJump) {
        translateJump();
      }
    });
    glide.mount();
    return function () {
      return glide.destroy();
    };
  }, []);
  return React.createElement("div", {
    className: className,
    ref: ref || glideRef,
    style: _extends({}, styles, {}, style)
  }, React.createElement("div", {
    className: "slider__track glide__track",
    "data-glide-el": "track"
  }, React.createElement("ul", {
    className: "glide__slides"
  }, children.map(function (slide, index) {
    return React.createElement(Fragment, {
      key: index
    }, customSlideAnimation ? React.createElement(CSSTransition, {
      "in": index === activeSlide,
      timeout: customSlideAnimation.timeout,
      classNames: customSlideAnimation.classNames,
      onEnter: customSlideAnimation.onEnter,
      onExit: customSlideAnimation.onExit
    }, slide) : React.createElement(Fragment, null, slide));
  }))), !hideArrows && React.createElement("div", {
    style: {
      height: 0
    },
    "data-glide-el": "controls"
  }, React.createElement("button", {
    "data-glide-dir": "<"
  }, React.createElement("span", {
    className: baseStyles.sliderArrow + " " + baseStyles.sliderArrowPrev,
    style: {
      top: adjustArrowYPosition ? adjustArrowYPosition : '50%'
    }
  }, leftArrowComponent ? leftArrowComponent : React.createElement(ArrowLeftIcon, {
    iconSize: arrowSize,
    color: arrowColor
  }))), React.createElement("button", {
    "data-glide-dir": ">"
  }, React.createElement("span", {
    className: baseStyles.sliderArrow + " " + baseStyles.sliderArrowNext,
    style: {
      top: adjustArrowYPosition ? adjustArrowYPosition : '50%'
    }
  }, rightArrowComponent ? rightArrowComponent : React.createElement(ArrowRightIcon, {
    iconSize: arrowSize,
    color: arrowColor
  })))));
});

var Slide = (function (_ref) {
  var children = _ref.children,
      className = _ref.className,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "className"]);

  return React.createElement("li", Object.assign({
    className: "glide__slide " + (className || '')
  }, props), children);
});

export default Glide;
export { Slide };
//# sourceMappingURL=index.modern.js.map
